==> wsmsg-0.2.tar.gz: wsmsg-0.2/src/wsmsg/common.py <==
from uuid import UUID, uuid4
from typing import NamedTuple
from asyncio import Event
from msgpack import packb, unpackb
from websockets.legacy.protocol import WebSocketCommonProtocol 

class Message(NamedTuple):
    uid: bytes
    reference: bytes
    channel: str
    subject: str
    data: any
    def __repr__(self):
        elements = [
            UUID(bytes=self.uid).hex,
            UUID(bytes=self.reference).hex if self.reference else None,
            self.channel,
            self.subject
        ]
        return f"<Message({', '.join([str(e) for e in elements])})>"

class Connection(object):

    def __init__(self, ws: WebSocketCommonProtocol, debug=False):
        self._debug = debug
        self._ws = ws
        if self._debug:
            print(f"Creating connection {self.id}")
        self._ack = Event()
        self._ack.set()
        # self._unacked: list[bytes] = []

    def __repr__(self):
        return f"<Connection {self.id.str}>"

    @property
    def id(self):
        return self._ws.id

    async def send(self, msg: Message):
        await self._ws.send(packb(msg))
        await self._ack.wait()

    async def recv(self) -> Message:
        while True:
            msg = Message(*unpackb(await self._ws.recv()))
            if self._debug:
                print(f"{self.id.hex[20:]} <- {msg}")
            if msg.channel == 'system' and msg.subject == 'ack':
                self._ack.set()
                continue
            else:
                await self._ws.send(packb(Message(uuid4().bytes, msg.uid, 'system', 'ack', None)))
            return msg

    async def close(self):
        if self._debug:
            print(f"Closing connection {self.id}")
        # self._unacked = []
        # self._CTS.set()
        self._ack.set()
        await self._ws.close()

==> wsmsg-0.3.tar.gz: wsmsg-0.3/src/wsmsg/common.py <==
from uuid import UUID, uuid4
from typing import NamedTuple
from asyncio import Event
from msgpack import packb, unpackb
from websockets.legacy.protocol import WebSocketCommonProtocol 

class Message(NamedTuple):
    uid: bytes
    reference: bytes
    channel: str
    subject: str
    data: any
    def __repr__(self):
        elements = [
            UUID(bytes=self.uid).hex,
            UUID(bytes=self.reference).hex if self.reference else None,
            self.channel,
            self.subject
        ]
        return f"<Message({', '.join([str(e) for e in elements])})>"

class Connection(object):

    def __init__(self, ws: WebSocketCommonProtocol, debug=False):
        self._debug = debug
        self._ws = ws
        if self._debug:
            print(f"Creating connection {self.id}")
        self._ack = Event()
        self._ack.set()
        # self._unacked: list[bytes] = []

    def __repr__(self):
        return f"<Connection {self.id.hex}>"

    @property
    def id(self) -> UUID:
        return self._ws.id

    async def send(self, msg: Message):
        await self._ws.send(packb(msg))
        await self._ack.wait()

    async def recv(self) -> Message:
        while True:
            msg = Message(*unpackb(await self._ws.recv()))
            if self._debug:
                print(f"{self.id.hex[20:]} <- {msg}")
            if msg.channel == 'system' and msg.subject == 'ack':
                self._ack.set()
                continue
            else:
                await self._ws.send(packb(Message(uuid4().bytes, msg.uid, 'system', 'ack', None)))
            return msg

    async def close(self):
        if self._debug:
            print(f"Closing connection {self.id.hex}")
        # self._unacked = []
        # self._CTS.set()
        self._ack.set()
        if not self._ws.closed:
            await self._ws.close()
